Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: lib/src/source/cached.dart

Issue 2044253003: Refactor Source and SourceRegistry. (Closed) Base URL: git@github.com:dart-lang/pub.git@master
Patch Set: Rename LiveSource to BoundSource. Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/src/source.dart ('k') | lib/src/source/git.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/src/source/cached.dart
diff --git a/lib/src/source/cached.dart b/lib/src/source/cached.dart
index e492f54c36af40207284c9afd8a14734c0c66b9d..8a40bc3bcba4864c4e238afbacb75dc4250740e5 100644
--- a/lib/src/source/cached.dart
+++ b/lib/src/source/cached.dart
@@ -12,17 +12,18 @@ import '../pubspec.dart';
import '../source.dart';
import '../utils.dart';
/// Base class for a [Source] that installs packages into pub's [SystemCache].
///
/// A source should be cached if it requires network access to retrieve
/// packages or the package needs to be "frozen" at the point in time that it's
/// installed. (For example, Git packages are cached because installing from
/// the same repo over time may yield different commits.)
-abstract class CachedSource extends Source {
+abstract class CachedSource extends BoundSource {
/// The root directory of this source's cache within the system cache.
///
/// This shouldn't be overridden by subclasses.
- String get systemCacheRoot => path.join(systemCache.rootDir, name);
+ String get systemCacheRoot => path.join(systemCache.rootDir, source.name);
/// If [id] is already in the system cache, just loads it from there.
///
« no previous file with comments | « lib/src/source.dart ('k') | lib/src/source/git.dart » ('j') | no next file with comments »
@@ -12,17 +12,18 @@ import '../pubspec.dart';
import '../source.dart';
import '../utils.dart';
-/// Base class for a [Source] that installs packages into pub's [SystemCache].
+/// Base class for a [BoundSource] that installs packages into pub's
+/// [SystemCache].
///
/// A source should be cached if it requires network access to retrieve

Powered by Google App Engine
This is Rietveld 408576698